# GEM Derivatives Library

Contents of Library
* Options
  * Vanilla
    * Black Scholes (b = ir)
    * Merton Stock Option (b = ir - dividend yield)
    * Black76, option on Futures (b = 0)
    * Black76, fully margined options account (b = 0 and ir = 0)
    * Currency Option, b = ir - foreign risk free rate
  * Multi Asset
    * Duel Asset Spread Option
  * Barrier
    * Digital
* Correlated Linear
  * Load Following Imbalance
  * Ancillary Imbalance
